@@ -203,6 +203,7 @@ class Model(model.Model):
             'cola_fontdiff': '',
             'cola_fontdiff_size': 12,
             'cola_savewindowsettings': False,
+            'cola_tabwidth': 8,
             'merge_keepbackup': True,
             'merge_tool': os.getenv('MERGETOOL', 'xxdiff'),
             'gui_editor': os.getenv('EDITOR', 'gvim'),
@@ -693,14 +694,11 @@ class Model(model.Model):
         fh.close()
 
         # Run 'git commit'
-        (status, stdout, stderr) = self.git.commit(F=tmpfile,
-                                                   v=True,
-                                                   amend=amend,
-                                                   with_extended_output=True)
+        status, out = self.git.commit(F=tmpfile, v=True, amend=amend,
+                                      with_extended_output=True,
+                                      with_stderr=True)
         os.unlink(tmpfile)
-
-        return (status, stdout+stderr)
-
+        return status, out
 
     def diffindex(self):
         return self.git.diff(unified=self.diff_context,
@@ -857,14 +855,13 @@ class Model(model.Model):
             head = 'HEAD^'
         (staged, modified, unmerged, untracked) = ([], [], [], [])
         try:
-            for name in self.git.diff_index(head).splitlines():
-                rest, name = name.split('\t')
+            for line in self.git.diff_index(head).splitlines():
+                rest, name = line.split('\t')
                 status = rest[-1]
-                name = eval_path(name)
                 if status == 'M' or status == 'D':
-                    modified.append(name)
+                    modified.append(eval_path(name))
                 elif status == 'A':
-                    unmerged.append(name)
+                    unmerged.append(eval_path(name))
         except:
             # handle git init
             for name in (self.git.ls_files(modified=True, z=True)
@@ -873,16 +870,18 @@ class Model(model.Model):
                     modified.append(decode(name))
 
         try:
-            for name in (self.git.diff_index(head, cached=True)
+            for line in (self.git.diff_index(head, cached=True)
                                  .splitlines()):
-                rest, name = name.split('\t')
+                rest, name = line.split('\t')
                 status = rest[-1]
                 name = eval_path(name)
                 if status  == 'M':
                     staged.append(name)
                     # is this file partially staged?
-                    diff = self.git.diff('--', name, name_only=True, z=True)
-                    if not diff.strip():
+                    status, out = self.git.diff('--', name,
+                                                name_only=True, exit_code=True,
+                                                with_extended_output=True)
+                    if status == 0:
                         modified.remove(name)
                     else:
                         self.partially_staged.add(name)
@@ -895,6 +894,7 @@ class Model(model.Model):
                     modified.remove(name)
                 elif status == 'U':
                     unmerged.append(name)
+                    modified.remove(name)
         except:
             # handle git init
             for name in self.git.ls_files(z=True).strip('\0').split('\0'):
@@ -906,11 +906,6 @@ class Model(model.Model):
             if name:
                 untracked.append(decode(name))
 
-        # remove duplicate merged and modified entries
-        for u in unmerged:
-            if u in modified:
-                modified.remove(u)
-
         return (staged, modified, unmerged, untracked)
 
     def reset_helper(self, args):
@@ -951,6 +946,7 @@ class Model(model.Model):
             'verbose': True,
             'tags': tags,
             'rebase': rebase,
+            'with_stderr': True,
         }
         return (args, kwargs)
 
